@@ -1,6 +1,6 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /* 
- * Copyright (C) 2001-2005 Bastien Nocera <hadess@hadess.net>
+ * Copyright (C) 2001-2006 Bastien Nocera <hadess@hadess.net>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -165,7 +165,8 @@ totem_action_exit (Totem *totem)
 {
 	GdkDisplay *display = NULL;
 
-	popup_timeout_remove (totem);
+	if (totem != NULL)
+		popup_timeout_remove (totem);
 
 	if (gtk_main_level () > 0)
 		gtk_main_quit ();
@@ -794,8 +795,6 @@ totem_action_set_mrl_with_warning (Totem *totem, const char *mrl,
 		/* Take a screenshot */
 		totem_main_set_sensitivity ("tmw_take_screenshot_menu_item",
 				retval);
-		gtk_widget_set_sensitive
-			(GTK_WIDGET (totem->properties), retval);
 
 		/* Set the playlist */
 		totem_playlist_set_playing (totem->playlist, retval);
@@ -824,7 +823,6 @@ totem_action_set_mrl_with_warning (Totem *totem, const char *mrl,
 			g_free (totem->mrl);
 			totem->mrl = NULL;
 			play_pause_set_label (totem, STATE_STOPPED);
-			bacon_video_widget_set_logo_mode (totem->bvw, TRUE);
 		}
 	}
 	update_buttons (totem);
@@ -1930,7 +1928,9 @@ on_help_activate (GtkButton *button, Totem *totem)
 static void
 on_about1_activate (GtkButton *button, Totem *totem)
 {
-	GdkPixbuf *pixbuf = NULL;
+	char *backend_version, *description;
+	const char *frontend_type;
+
 	const char *authors[] =
 	{
 		"Bastien Nocera <hadess@hadess.net>",
@@ -1944,8 +1944,6 @@ on_about1_activate (GtkButton *button, Totem *totem)
 		"Chee Bin Hoh <cbhoh@gnome.org>",
 		NULL
 	};
-	char *backend_version, *description;
-	char *filename;
 
 	if (totem->about != NULL)
 	{
@@ -1953,33 +1951,32 @@ on_about1_activate (GtkButton *button, Totem *totem)
 		return;
 	}
 
-	filename = g_build_filename (DATADIR,
-			"totem", "media-player-48.png", NULL);
-	pixbuf = gdk_pixbuf_new_from_file (filename, NULL);
-	g_free (filename);
+#ifdef HAVE_GTK_ONLY
+	frontend_type = N_("GTK+");
+#else
+	frontend_type = N_("GNOME");
+#endif
 
 	backend_version = bacon_video_widget_get_backend_name (totem->bvw);
-	description = g_strdup_printf (_("Movie Player using %s"),
-				backend_version);
+	/* This lists the back-end and front-end types and versions, such as
+	 * Movie Player using GStreamer 0.10.1 and GNOME */
+	description = g_strdup_printf (_("Movie Player using %s and %s"),
+				       backend_version, _(frontend_type));
 
 	totem->about = g_object_new (GTK_TYPE_ABOUT_DIALOG,
-			"name", _("Totem"),
-			"version", PACKAGE_VERSION,
-			"copyright", _("Copyright \xc2\xa9 2002-2005 Bastien Nocera"),
-			"comments", description,
-			"authors", authors,
-			"documenters", documenters,
-			"artists", artists, 
-			"translator-credits", _("translator-credits"),
-			"logo", pixbuf,
-			NULL);
+				     "version", PACKAGE_VERSION,
+				     "copyright", _("Copyright \xc2\xa9 2002-2006 Bastien Nocera"),
+				     "comments", description,
+				     "authors", authors,
+				     "documenters", documenters,
+				     "artists", artists,
+				     "translator-credits", _("translator-credits"),
+				     "logo-icon-name", "media-player-48",
+				     NULL);
 
 	g_free (backend_version);
 	g_free (description);
 
-	if (pixbuf != NULL)
-		gdk_pixbuf_unref (pixbuf);
-
 	g_object_add_weak_pointer (G_OBJECT (totem->about),
 			(gpointer *)&totem->about);
 	gtk_window_set_transient_for (GTK_WINDOW (totem->about),
@@ -3495,6 +3492,7 @@ totem_volume_create (void)
 
 	widget = bacon_volume_button_new (GTK_ICON_SIZE_SMALL_TOOLBAR,
 					  0, 100, 1);
+	gtk_widget_set_sensitive (widget, FALSE);
 	gtk_widget_show (widget);
 
 	return widget;
@@ -3504,7 +3502,6 @@ int
 main (int argc, char **argv)
 {
 	Totem *totem;
-	char *filename;
 	GConfClient *gc;
 
 	bindtextdomain (GETTEXT_PACKAGE, GNOMELOCALEDIR);
@@ -3532,6 +3529,7 @@ main (int argc, char **argv)
 #endif /* HAVE_GTK_ONLY */
 
 	g_set_application_name (_("Totem Movie Player"));
+	gtk_window_set_default_icon_name ("media-player-48");
 
 	gnome_vfs_init ();
 
@@ -3577,10 +3575,7 @@ main (int argc, char **argv)
 		totem_action_exit (NULL);
 
 	totem->win = glade_xml_get_widget (totem->xml, "totem_main_window");
-	filename = totem_interface_get_full_path ("media-player-48.png");
-	gtk_window_set_default_icon_from_file (filename, NULL);
-	g_free (filename);
-
+	
 	totem_named_icons_init (totem, FALSE);
 
 	/* The sidebar */
@@ -3639,6 +3634,7 @@ main (int argc, char **argv)
 	/* Show ! (again) the video widget this time. */
 	video_widget_create (totem);
 	long_action ();
+	gtk_widget_grab_focus (GTK_WIDGET (totem->bvw));
 	bacon_video_widget_set_logo (totem->bvw, LOGO_PATH);
 
 	/* The prefs after the video widget is connected */
